@@ -90,6 +90,11 @@ private:
                     simdutf::encoding_type enc2, simdutf::encoding_type enc3);
 
 private:
+  void run_validate_ascii(const simdutf::implementation &implementation,
+                          size_t iterations);
+  void
+  run_validate_ascii_with_errors(const simdutf::implementation &implementation,
+                                 size_t iterations);
   void run_validate_utf8(const simdutf::implementation &implementation,
                          size_t iterations);
   void
