@@ -10,11 +10,11 @@
 #include <tests/helpers/test.h>
 
 namespace {
-std::array<size_t, 7> input_size{7, 16, 12, 64, 67, 128, 256};
+constexpr std::array<size_t, 7> input_size{7, 16, 12, 64, 67, 128, 256};
+constexpr simdutf::endianness LE = simdutf::endianness::LITTLE;
 
 using simdutf::tests::helpers::transcode_utf8_to_utf16_test_base;
 
-constexpr size_t trials = 1000;
 constexpr size_t fix_size = 512;
 } // namespace
 
@@ -129,7 +129,7 @@ TEST(issue_213) {
   ASSERT_EQUAL(r.count, 0);
 }
 
-TEST_LOOP(trials, convert_pure_ASCII) {
+TEST_LOOP(convert_pure_ASCII) {
   size_t counter = 0;
   auto generator = [&counter]() -> uint32_t { return counter++ & 0x7f; };
 
@@ -147,13 +147,13 @@ TEST_LOOP(trials, convert_pure_ASCII) {
   };
 
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(generator, size);
+    transcode_utf8_to_utf16_test_base test(LE, generator, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
 }
 
-TEST_LOOP(trials, convert_1_or_2_UTF8_bytes) {
+TEST_LOOP(convert_1_or_2_UTF8_bytes) {
   simdutf::tests::helpers::RandomInt random(
       0x0000, 0x07ff, seed); // range for 1 or 2 UTF-8 bytes
 
@@ -169,13 +169,13 @@ TEST_LOOP(trials, convert_1_or_2_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
 }
 
-TEST_LOOP(trials, convert_1_or_2_or_3_UTF8_bytes) {
+TEST_LOOP(convert_1_or_2_or_3_UTF8_bytes) {
   // range for 1, 2 or 3 UTF-8 bytes
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd7ff}, {0xe000, 0xffff}}, seed);
@@ -192,13 +192,13 @@ TEST_LOOP(trials, convert_1_or_2_or_3_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
 }
 
-TEST_LOOP(trials, convert_3_or_4_UTF8_bytes) {
+TEST_LOOP(convert_3_or_4_UTF8_bytes) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0800, 0xd800 - 1}, {0xe000, 0x10ffff}},
       seed); // range for 3 or 4 UTF-8 bytes
@@ -215,13 +215,13 @@ TEST_LOOP(trials, convert_3_or_4_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
 }
 
-TEST_LOOP(trials, convert_3_UTF8_bytes) {
+TEST_LOOP(convert_3_UTF8_bytes) {
   simdutf::tests::helpers::RandomInt random(0x0800, 0xd800 - 1,
                                             seed); // range for 3 UTF-8 bytes
 
@@ -237,17 +237,17 @@ TEST_LOOP(trials, convert_3_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
 }
 
-TEST_LOOP(trials, header_bits_error) {
+TEST_LOOP(header_bits_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
 
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
 
   for (unsigned int i = 0; i < fix_size; i++) {
     if ((test.input_utf8[i] & 0b11000000) !=
@@ -269,10 +269,10 @@ TEST_LOOP(trials, header_bits_error) {
   }
 }
 
-TEST_LOOP(trials, too_short_error) {
+TEST_LOOP(too_short_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
   unsigned int leading_byte_pos = 0;
   for (unsigned int i = 0; i < fix_size; i++) {
     if ((test.input_utf8[i] & 0b11000000) ==
@@ -281,7 +281,7 @@ TEST_LOOP(trials, too_short_error) {
       auto procedure = [&implementation,
                         &leading_byte_pos](const char *utf8, size_t size,
                                            char16_t *utf16) -> size_t {
-        simdutf::result res =
+        const simdutf::result res =
             implementation.convert_utf8_to_utf16le_with_errors(utf8, size,
                                                                utf16);
         ASSERT_EQUAL(res.error, simdutf::error_code::TOO_SHORT);
@@ -298,17 +298,17 @@ TEST_LOOP(trials, too_short_error) {
   }
 }
 
-TEST_LOOP(trials, too_long_error) {
+TEST_LOOP(too_long_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
   for (unsigned int i = 1; i < fix_size; i++) {
     if (((test.input_utf8[i] & 0b11000000) !=
          0b10000000)) { // Only process leading bytes by making them
                         // continuation bytes
       auto procedure = [&implementation, &i](const char *utf8, size_t size,
                                              char16_t *utf16) -> size_t {
-        simdutf::result res =
+        const simdutf::result res =
             implementation.convert_utf8_to_utf16le_with_errors(utf8, size,
                                                                utf16);
         ASSERT_EQUAL(res.error, simdutf::error_code::TOO_LONG);
@@ -323,17 +323,17 @@ TEST_LOOP(trials, too_long_error) {
   }
 }
 
-TEST_LOOP(trials, overlong_error) {
+TEST_LOOP(overlong_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
   for (unsigned int i = 1; i < fix_size; i++) {
     if ((unsigned char)test.input_utf8[i] >=
         (unsigned char)0b11000000) { // Only non-ASCII leading bytes can be
                                      // overlong
       auto procedure = [&implementation, &i](const char *utf8, size_t size,
                                              char16_t *utf16) -> size_t {
-        simdutf::result res =
+        const simdutf::result res =
             implementation.convert_utf8_to_utf16le_with_errors(utf8, size,
                                                                utf16);
         ASSERT_EQUAL(res.error, simdutf::error_code::OVERLONG);
@@ -361,10 +361,10 @@ TEST_LOOP(trials, overlong_error) {
   }
 }
 
-TEST_LOOP(trials, too_large_error) {
+TEST_LOOP(too_large_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
   for (unsigned int i = 1; i < fix_size; i++) {
     if ((test.input_utf8[i] & 0b11111000) ==
         0b11110000) { // Can only have too large error in 4-bytes case
@@ -387,16 +387,16 @@ TEST_LOOP(trials, too_large_error) {
   }
 }
 
-TEST_LOOP(trials, surrogate_error) {
+TEST_LOOP(surrogate_error) {
   simdutf::tests::helpers::RandomIntRanges random(
       {{0x0000, 0xd800 - 1}, {0xe000, 0x10ffff}}, seed);
-  transcode_utf8_to_utf16_test_base test(random, fix_size);
+  transcode_utf8_to_utf16_test_base test(LE, random, fix_size);
   for (unsigned int i = 1; i < fix_size; i++) {
     if ((test.input_utf8[i] & 0b11110000) ==
         0b11100000) { // Can only have surrogate error in 3-bytes case
       auto procedure = [&implementation, &i](const char *utf8, size_t size,
                                              char16_t *utf16) -> size_t {
-        simdutf::result res =
+        const simdutf::result res =
             implementation.convert_utf8_to_utf16le_with_errors(utf8, size,
                                                                utf16);
         ASSERT_EQUAL(res.error, simdutf::error_code::SURROGATE);
