@@ -7,9 +7,7 @@
 #include <tests/helpers/test.h>
 #include <tests/helpers/utf16.h>
 
-constexpr size_t trials = 1000;
-
-TEST_LOOP(trials, validate_utf16be_ascii) {
+TEST_LOOP(validate_utf16be_ascii) {
   simdutf::tests::helpers::random_utf16 generator{seed, 1, 0};
   auto utf16{generator.generate_be(512, seed)};
   generator.to_ascii_be(utf16);
@@ -20,7 +18,7 @@ TEST_LOOP(trials, validate_utf16be_ascii) {
       implementation.validate_utf16be_as_ascii(utf16.data(), utf16.size()));
 }
 
-TEST_LOOP(trials, validate_utf16be_returns_true_for_valid_input_single_words) {
+TEST_LOOP(validate_utf16be_returns_true_for_valid_input_single_words) {
   simdutf::tests::helpers::random_utf16 generator{seed, 1, 0};
   const auto utf16{generator.generate_be(512, seed)};
 
@@ -28,16 +26,14 @@ TEST_LOOP(trials, validate_utf16be_returns_true_for_valid_input_single_words) {
       reinterpret_cast<const char16_t *>(utf16.data()), utf16.size()));
 }
 
-TEST_LOOP(trials,
-          validate_utf16be_returns_true_for_valid_input_surrogate_pairs_short) {
+TEST_LOOP(validate_utf16be_returns_true_for_valid_input_surrogate_pairs_short) {
   simdutf::tests::helpers::random_utf16 generator{seed, 0, 1};
   const auto utf16{generator.generate_be(8)};
   ASSERT_TRUE(implementation.validate_utf16be(
       reinterpret_cast<const char16_t *>(utf16.data()), utf16.size()));
 }
 
-TEST_LOOP(trials,
-          validate_utf16be_returns_true_for_valid_input_surrogate_pairs) {
+TEST_LOOP(validate_utf16be_returns_true_for_valid_input_surrogate_pairs) {
   simdutf::tests::helpers::random_utf16 generator{seed, 0, 1};
   const auto utf16{generator.generate_be(512)};
   ASSERT_TRUE(implementation.validate_utf16be(
@@ -72,7 +68,7 @@ TEST(validate_utf16be_returns_true_for_empty_string) {
       is in error [...]
 */
 TEST_LOOP(
-    10, validate_utf16be_returns_false_when_input_has_wrong_first_word_value) {
+    validate_utf16be_returns_false_when_input_has_wrong_first_word_value) {
   simdutf::tests::helpers::random_utf16 generator{seed, 1, 0};
   auto utf16{generator.generate_be(128)};
   const size_t len = utf16.size();
